@@ -46,6 +46,13 @@ sub validate_config
   
   $s->_fixup_path( 'application_root' );
   
+  die "web_application.domain_re is not defined"
+    unless defined($s->{domain_re});
+  
+  eval { 'whatever' =~ m/$s->{domain_re}/ };
+  die "web_application.domain_re has errors: $@"
+    if $@;
+  
   die "web_application.application_root '@{[ $s->application_root ]}' does not exist"
     unless -d $s->application_root;
   
@@ -204,6 +211,8 @@ __END__
 
 =head1 NAME
 
+Apache2::ASP::Config - Configuration object for Apache2::ASP web applications.
+
 =head1 READ THIS FIRST
 
 B<NOTE:> This module requires the environment variable C<$ENV{APACHE2_ASP_APPLICATION_ROOT}> to be set 
